#======================  Personal Space Project =============================================

#======================  Experiment 3 Concert Pairs  =============================================

# This file is for:
#   => concert pairs singles
#   => choices WITH no-choice and WITHOUT no-choice option 
#   => total of 54 tasks per respondent (24 FC and 30 NC)
#   => no covariates

# generates files:
#     E3-Concert-Pairs.FC/NC:NC
#     E3-Concert-Pairs.FC/NC:FC


###  ----------------------------------------------------------------------------------------
### Generate input for the hierarchical model estimation (lgtdata)
# ----------------------------------------------------------------------------------------

# Continuous X for rows and columns

dataSeats       <-   read.csv("Study3 Seats.csv")
dataLayouts      <-  read.csv("Study3 Layouts.csv")
dataQualtrics <-     read.csv("Concert_1701_post_qualtrics_forR.csv")
dataDuplicateGigs <- read.csv("DuplicateGigs.csv")

length(levels(factor(dataLayouts$ParticipantID) ) )  #525
length(levels(factor(dataSeats$ParticipantID) ) )    #525
length(levels(factor(dataQualtrics$V1) ) )           #426
nhh = length(levels(factor(dataQualtrics$wid) ) )
list_PIDs = levels(factor(dataQualtrics$wid) )        #426
list_PIDs_seats = levels(factor(dataSeats$Gig) )[-1]  #508

#-------------------------------------------------------------------------------------------------------
# generate list with X locational in original scale/coding
#-------------------------------------------------------------------------------------------------------

error_list = NULL
missingY=NULL
lgtdata_XL_original_pairs = list()
j=1
count_err_rec=0    # error in choices (y), ex. no record or chose occupied seats
count_chosen_nottogether=0
for(h in 1:length(list_PIDs))    # for each respondent
{     
  dataResp_h = dataSeats[c(which(dataSeats$Gig==list_PIDs[h])),]      # all data for one respondent
  dataResp_h = dataResp_h[c(which(dataResp_h$Available==1)),]         # remove seats that are not available
  if(length(which(dataDuplicateGigs[,1]==list_PIDs[h]))>0)            # for 12 people the same Gig had 2+ PIDs, so take the latest attempt
  {
    dataResp_h = dataResp_h[c(which(dataResp_h$ParticipantID==toString(dataDuplicateGigs[which(dataDuplicateGigs[,1]==list_PIDs[h]),2]) )),]
  }
  list_Layouts = as.numeric(levels(factor(dataResp_h$LayoutID)))      # get all Layout IDs
  nch = length(list_Layouts)                                          # number of choices  
  m=1
  lgtdata_XL_original_pairs[[h]]=list()
  for(choicetask in 1:nch)  # for each choice task within respondents
  {
    X_L = NULL
    y = NULL
    Xtemp=dataResp_h[which(dataResp_h$LayoutID==list_Layouts[choicetask]),] # select all seats available for the choice task
    if(nrow(Xtemp)>0)
    { list_rows=as.numeric(levels(factor(Xtemp$Y)))                         # list of rows in which seats were available  
      for(i in 1:length(list_rows))                                         # find pair seats in each row
      {
        Xtemp_row=Xtemp[which(Xtemp$Y==list_rows[i]),] 
        list_seats_inrows=sort(as.numeric(levels(factor(Xtemp_row$X))))
        findpairs = which((c(list_seats_inrows,0)-c(0,list_seats_inrows))[-1]==1)
        if(length(findpairs)>0)
        {   # coding pair location as mean col number of (seat1, seat2)
            X_L_temp = cbind(c(rep(list_rows[i],length(findpairs))),list_seats_inrows[findpairs]+0.5)  # generate X_L[row, col] portion for one row
            choosenPair = which(X_L_temp[,2]==mean(Xtemp_row[which(Xtemp_row$Chosen==1),5]))
            if(length(choosenPair)>0) { 
              y = ifelse(is.numeric(X_L)==T,nrow(X_L),0) + choosenPair }
            X_L = rbind(X_L, X_L_temp)  # append X design rows for each row 
        }
       }
      Cond = dataLayouts[dataLayouts$LayoutID==list_Layouts[choicetask],][1,]
      if(Cond[10]==1) {                          # if skip/no-choice is allowed, check if y=nochoice and add a row in X
        X_L = rbind(X_L, c(rep(0,2)))            # add row for the no-choice option 
        if(is.numeric(y)==F)  {
          if(sum(Xtemp[,8])==0) {y=nrow(X_L)}                            # selected no-choice option, 
          else { count_chosen_nottogether = count_chosen_nottogether+1 } # otherwise possibly picked separate seats, so ignore the choice
         }  
      }
      else{ if(is.numeric(y)==F )  {missingY = rbind(missingY,c(list_Layouts[choicetask],list_PIDs[h] )) } }}
      if(length(y)>0)
      { lgtdata_XL_original_pairs[[h]][[m]]=list(y=y, X=X_L, p=nrow(X_L), choicenumber=choicetask, PID=list_PIDs[h], LayoutID = list_Layouts[choicetask], 
              Busy = Cond[11], NRows = Cond[4], NCols = Cond[3], TimeLeft = Cond[12],
              Height = Cond[5], Width = Cond[6], LSpace = Cond[7], Tspace = Cond[8], SkipAllowed = Cond[10] )
        m=m+1
      }
      else {  count_err_rec=count_err_rec+1
              error_list = rbind(error_list,c(list_PIDs[h],Xtemp[h,2],list_Layouts[choicetask],choicetask))
      }
  }
}
# takes about 3-5 min to generate
check_number_choices = matrix(0,ncol=2,nrow=length(lgtdata_XL_original_pairs))
for(h in 1:length(lgtdata_XL_original_pairs)) {
  check_number_choices[h,1] = lgtdata_XL_original_pairs[[h]][[1]]$PID
  check_number_choices[h,2] = as.numeric(length(lgtdata_XL_original_pairs[[h]]))
  }
# 426 respondents
table(check_number_choices[,2])
length(levels(factor(error_list[,1])))

#-------------------------------------------------------------------------------------------------------
# generate list of PS components for pairs
#-------------------------------------------------------------------------------------------------------

lgtdata_XL_original_pairs_withPS_regions = list()
#test = function(a){
for(h in 1:length(lgtdata_XL_original_pairs))    # for each respondent
{
     dataResp_h = dataSeats[c(which(dataSeats$Gig==lgtdata_XL_original_pairs[[h]][[1]]$PID)),]    # all data for one respondent
     dataResp_h = dataResp_h[c(which(dataResp_h$Available==1)),]                             # remove seats that are not available
     if(length(which(dataDuplicateGigs[,1]==list_PIDs[h]))>0)             # for 12 people the same Gig had 2+ PIDs, so take the latest attempt
      {
         dataResp_h = dataResp_h[c(which(dataResp_h$ParticipantID==toString(dataDuplicateGigs[which(dataDuplicateGigs[,1]==list_PIDs[h]),2]) )),]
      }
     lgtdata_XL_original_pairs_withPS_regions[[h]] =list()
     nobs = length(lgtdata_XL_original_pairs[[h]])
     for(choicetask in 1:nobs)                          # for each choicetask
      {
        X_hh_task = lgtdata_XL_original_pairs[[h]][[choicetask]]$X           # select all seats (pair coding) for the choice task
        # select all seats available in the room for the choice task
        X_hh_task_allavailable = dataResp_h[which(dataResp_h$LayoutID==lgtdata_XL_original_pairs[[h]][[choicetask]]$LayoutID),] 
        choiceset=lgtdata_XL_original_pairs[[h]][[choicetask]]$p
        Nrows = as.numeric(lgtdata_XL_original_pairs[[h]][[choicetask]]$NRows)
        Ncols = as.numeric(lgtdata_XL_original_pairs[[h]][[choicetask]]$NCols)
        # create seats table
        seats_occupied = matrix(1, ncol = Ncols+6, nrow = Nrows+6)
        seats_occupied[,1:3] = seats_occupied[,(Ncols+4):(Ncols+6)] = 0
        seats_occupied[1:3,] = seats_occupied[(Nrows+4):(Nrows+6),] = 0
        for(i in 4:(Nrows+3))
        { seatsavailable = sort(X_hh_task_allavailable[X_hh_task_allavailable[,6]==(i-3),5]) +3
          seats_occupied[i,seatsavailable] = 0
        }
        X_hh_PS2=matrix(0,ncol=15,nrow=nrow(X_hh_task))
        # 1, 2,  3,      4,       5,        6,             7,          8,                9,               10,            11,      12,     13
        # L, R, intLR, countF, countB,  dummyAisleLR, dummyFirstRow, dummyLastRow
        # L, R, intLR, countF, countB,  dummyAisleLR, dummyFirstRow, dummyLastRow, countFrontCorners, countBackCorners, propR1, propR2, propR3
        for(choice in 1:(nrow(X_hh_task)))
        { rnumber = X_hh_task[choice,1]         # unshifted
          if(rnumber>0) {  # in case it is the non-choice row for some choices
            c1number = X_hh_task[choice,2]-0.5  # unshifted
            c2number = X_hh_task[choice,2]+0.5  # unshifted
            # L:  
            X_hh_PS2[choice,1] = seats_occupied[rnumber+3,c1number+2]
            # R:  
            X_hh_PS2[choice,2] = seats_occupied[rnumber+3,c2number+4]
            # countF:  
            X_hh_PS2[choice,4] = seats_occupied[rnumber+2,c1number+3] + seats_occupied[rnumber+2,c2number+3]
            # countB:  
            X_hh_PS2[choice,5] = seats_occupied[rnumber+4,c1number+3] + seats_occupied[rnumber+4,c2number+3]
            # dummyAisleLR:   (!!! coding is different for Aisles to make the reference point 0=no one arround)
            X_hh_PS2[choice,6] = ifelse(c1number==1,0,ifelse(c2number==Ncols,0,1))
            # dummyFirstRow:  (!!! coding is different for Aisles to make the reference point 0=no one arround) 
            X_hh_PS2[choice,7] = ifelse(rnumber==1,0,1)
            # dummyLastRow:  
            X_hh_PS2[choice,8] = ifelse(rnumber==Nrows,1,0)
            # countFrontCorners:  
            X_hh_PS2[choice,9] = seats_occupied[rnumber+2,c1number+2] + seats_occupied[rnumber+2,c2number+4]
            # countBackCorners:  
            X_hh_PS2[choice,10] = seats_occupied[rnumber+4,c1number+2] + seats_occupied[rnumber+4,c2number+4]
            ## Region 1
            X_hh_PS2[choice,11] = sum(seats_occupied[(rnumber+2):(rnumber+4),(c1number+2):(c2number+4)])/10
            ## Region 2
            X_hh_PS2[choice,12] = sum(seats_occupied[(rnumber+1):(rnumber+5),(c1number+1):(c2number+5)])/28
            ## Region 3
            X_hh_PS2[choice,13] = sum(seats_occupied[(rnumber):(rnumber+6),(c1number):(c2number+6)])/54
            X_hh_PS2[choice,14] = (sum(seats_occupied[(rnumber+1):(rnumber+5),(c1number+1):(c2number+5)]) -
                                   sum(seats_occupied[(rnumber+2):(rnumber+4),(c1number+2):(c2number+4)])) /18    ## Region 2 incrememntal proportion
            X_hh_PS2[choice,15] = (sum(seats_occupied[(rnumber):(rnumber+6),(c1number):(c2number+6)]) -
                                   sum(seats_occupied[(rnumber+1):(rnumber+5),(c1number+1):(c2number+5)])) /26    ## Region 3 incrememntal proportion
          }
        }
        X_hh_PS2[,3] = X_hh_PS2[,1]*X_hh_PS2[,2]                  # intLR
        #X_hh_PS = cbind(c(rep(0,(nrow(X_hh_task)-1)),1),X_hh_PS)     # ADD NON-CHOICE
        # 1, 2,    3,    4,       5,       6,                7,          8,                9,               10,            11,   12,     13,       14,         15
        # L, R, intLR, countF, countB,  dummyAisleLR, dummyFirstRow, dummyLastRow
        # L, R, intLR, countF, countB,  dummyAisleLR, dummyFirstRow, dummyLastRow, countFrontCorners, countBackCorners, propR1, propR2, propR3, incrR2prop, incrR3prop
        lgtdata_XL_original_pairs_withPS_regions[[h]][[choicetask]]=list(X_PS2=X_hh_PS2, 
                          p=nrow(X_hh_PS2),  choicenumber=lgtdata_XL_original_pairs[[h]][[choicetask]]$choicenumber,
                          PID=lgtdata_XL_original_pairs[[h]][[choicetask]]$PID,LayoutID = lgtdata_XL_original_pairs[[h]][[choicetask]]$LayoutID) 
      } 
}
#}
# takes about 2-3 min to get it  

#-------------------------------------------------------------------------------------------------------
# combine locational and PS and Qualtrics together (X_L original)
# recode coditions into dummy variables
#-------------------------------------------------------------------------------------------------------

lgtdata_LPS_originalXL_wQ = list()
for(h in 1:length(lgtdata_XL_original_pairs))    # for each respondent
{
  lgtdata_LPS_originalXL_wQ[[h]] = list()
  for(choicetask in 1:length(lgtdata_XL_original_pairs[[h]]))
  {  temp = lgtdata_XL_original_pairs[[h]][[choicetask]]
     X_cond = c(rep(0,10))
     X_cond[1] = 1                             # intercept
     X_cond[2] = ifelse(temp$Busy==40,1,0)     # 60 is the baseline
     X_cond[3] = ifelse(temp$Busy==80,1,0)     # 60 is the baseline
     X_cond[4] = ifelse(temp$NRows==20,1,0)    # landscape (20 col and 12 rows) is the baseline  (changed from two variables Nrows and Ncols 2017-10-27)
     X_cond[5] = ifelse(temp$TimeLeft=="A",1,0)    # "S" soon is the baseline
     #X_cond[6] = ifelse(temp$Height==15,1,0)   # one level
     #X_cond[7] = ifelse(temp$Width==15,1,0)    # one level
     #X_cond[6] = ifelse(temp$LSpace==20,1,0)    # 12 is the baseline
     X_cond[6] = ifelse(temp$Tspace==8,1,0)      # 5 is the baseline
     X_cond[7] = ifelse(temp$SkipAllowed==1,1,0) # 0 (no) is the baseline
     X_cond[8] = X_cond[5]*X_cond[2]               #TimeLeft*Den40
     X_cond[9] = X_cond[5]*X_cond[3]               #TimeLeft*Den80
     X_cond[10] = X_cond[5]*X_cond[7]              #TimeLeft*SkipAllowed

      lgtdata_LPS_originalXL_wQ[[h]][[choicetask]]=list (X_L = temp$X,y=temp$y,
           X_PS2 = lgtdata_XL_original_pairs_withPS_regions[[h]][[choicetask]]$X_PS2,
           X_cond = X_cond, PID=temp$PID, LayoutID = temp$LayoutID,
           p=temp$p, choicenumber=choicetask, NCol=temp$NCols,NRows=temp$NRows)
  }
  lgtdata_LPS_originalXL_wQ[[h]][[1]]$Qualtrics = dataQualtrics[which(dataQualtrics$gig==(lgtdata_XL_original_pairs[[h]][[1]]$PID)),c(8:9,11,14:39)]    
}
# takes about 1 min to get it  

#-------------------------------------------------------------------------------------------------------
# take locational and PS and Qualtrics together (X_L original): lgtdata_LPS_originalXL_wQ
# and recode locational X into 0 to 1 scale
#-------------------------------------------------------------------------------------------------------
 
lgtdata_LPS_XL01_wQ = list()
for(h in 1:length(lgtdata_LPS_originalXL_wQ))    # for each respondent
{
  lgtdata_LPS_XL01_wQ[[h]] = lgtdata_LPS_originalXL_wQ[[h]]
  for(choicetask in 1:length(lgtdata_XL_original_pairs[[h]]))
  {  Xc = lgtdata_LPS_originalXL_wQ[[h]][[choicetask]]$X_L                    #  (row, col)
     nc = as.numeric(lgtdata_XL_original_pairs[[h]][[choicetask]]$NCols)[1]
     nr = as.numeric(lgtdata_XL_original_pairs[[h]][[choicetask]]$NRows)[1]
     Xc1 = as.numeric(1/(nr*2) + (Xc[,1]-1)/nr)
     Xc2 = as.numeric(1/(nc*2) + (Xc[,2]-1)/nc)
     lgtdata_LPS_XL01_wQ[[h]][[choicetask]]$X_L = cbind(Xc1,Xc2)
     if(lgtdata_LPS_XL01_wQ[[h]][[choicetask]]$X_cond[7]==1)
     { lgtdata_LPS_XL01_wQ[[h]][[choicetask]]$X_L[nrow(Xc),] = c(0,0) }
  }
}
# takes about 1 min to get it  

#-------------------------------------------------------------------------------------------------------
# Generate clean file with 49+ choices per person
#-------------------------------------------------------------------------------------------------------
 
lgtdata_LPS_XL01_wQ_49plusch = list()
j=1
for(h in 1:length(lgtdata_LPS_XL01_wQ))    # for each respondent
{
  if(length(lgtdata_LPS_XL01_wQ[[h]])>48)
  {  lgtdata_LPS_XL01_wQ_49plusch[[j]] = lgtdata_LPS_XL01_wQ[[h]]
     j=j+1
  }
}
# takes 10 sec to get it 
length(lgtdata_LPS_XL01_wQ_49plusch)  # 383 out of 426


#-------------------------------------------------------------------------------------------------------
# Split file into with and without non-choice files, add intercept column for the withNonChoice sample
#-------------------------------------------------------------------------------------------------------
 
lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices = list()
lgtdata_LPS_XL01_wQ_49plusch_withNonChoice = list()
nvar_PS = ncol(lgtdata_LPS_XL01_wQ_49plusch[[1]][[1]]$X_PS)
nvar_PS2 = ncol(lgtdata_LPS_XL01_wQ_49plusch[[1]][[1]]$X_PS2)
for(h in 1:length(lgtdata_LPS_XL01_wQ_49plusch))    # for each respondent
{
  j=1
  m=1
  lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]]=list()
  lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]]=list()
  for(i in 1:length(lgtdata_LPS_XL01_wQ_49plusch[[h]]))
  {  
      if(lgtdata_LPS_XL01_wQ_49plusch[[h]][[i]]$X_cond[7]==0)
      {  lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[j]] = lgtdata_LPS_XL01_wQ_49plusch[[h]][[i]]
         lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[j]]$X_cond = lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[j]]$X_cond[-7]
         j=j+1
      }
      else
      {  lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]] = lgtdata_LPS_XL01_wQ_49plusch[[h]][[i]]
         lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_cond = lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_cond[-7]
         #  APPEND NON-CHOICE intercept here
         p = lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$p
         lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS = cbind(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS,rep(0,p))
         lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS[p,(nvar_PS+1)]=1  
         lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS2 = cbind(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS2,rep(0,p))
         lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[m]]$X_PS2[p,(nvar_PS2+1)]=1  
         m=m+1
      }
  }
}

nochoice_count = matrix(0,nrow=length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice),ncol=1)
allchoices_count = 0
for(hh in 1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice))
{
  allchoices_count = allchoices_count + length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]])
  for(j in 1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]])) { 
    nochoice_count[hh,1] = nochoice_count[hh,1] + ifelse(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]][[j]]$y==lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]][[j]]$p,1,0)
  }
}
nochoice_count
sum(nochoice_count)  # 1216 out of 11290  = 10.77%
allchoices_count
sum(nochoice_count) /allchoices_count

# remove all repondents with all no-choice selections
length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice)  # 383
nochoice_count_clean = matrix(0,nrow=length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice),ncol=2)
allchoices_count_clean  = 0
for(hh in 1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice))
{
  allchoices_count_clean = allchoices_count_clean + length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]])
  nochoice_count_clean[hh,2] = length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]])
  for(j in 1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]])) { 
    nochoice_count_clean[hh,1] = nochoice_count_clean[hh,1] + ifelse(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]][[j]]$y==lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[hh]][[j]]$p,1,0)
  }
}
table(nochoice_count_clean[,1])
which((nochoice_count_clean[,1]-nochoice_count_clean[,2])==0)


#-------------------------------------------------------------------------------------------------------
# break down to INSAMPLE and HOLDOUT so that there is 4 choices in HOLDOUT 
#-------------------------------------------------------------------------------------------------------
set.seed(5)
lgtdata_LPS_XL01_wQ_withNonChoice_INSAMPLE = list()   #####  Dataset reference: E3-Concert-Pairs.FC/NC:NC
lgtdata_LPS_XL01_wQ_withNonChoice_HOLDOUT = list()
for(h in 1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice))
{  indexHOLDOUT = sort(sample(c(1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]])),4,replace=FALSE))
   indexINSAMPLE = setdiff(c(1:length(lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]])),indexHOLDOUT)
   lgtdata_LPS_XL01_wQ_withNonChoice_INSAMPLE[[h]] = list()
   j=1
   for(r in indexINSAMPLE)    # for each respondent
   {  lgtdata_LPS_XL01_wQ_withNonChoice_INSAMPLE[[h]][[j]]=lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[r]]
      j=j+1
   }
   lgtdata_LPS_XL01_wQ_withNonChoice_INSAMPLE[[h]][[1]]$Qualtrics =  lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[1]]$Qualtrics
   j=1
   lgtdata_LPS_XL01_wQ_withNonChoice_HOLDOUT[[h]] = list()
   for(r in indexHOLDOUT)    # for each respondent
   {  lgtdata_LPS_XL01_wQ_withNonChoice_HOLDOUT[[h]][[j]] = lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[r]]
      j=j+1
   }
   lgtdata_LPS_XL01_wQ_withNonChoice_HOLDOUT[[h]][[1]]$Qualtrics =  lgtdata_LPS_XL01_wQ_49plusch_withNonChoice[[h]][[1]]$Qualtrics
}

lgtdata_LPS_XL01_wQ_ForcedChoices_INSAMPLE = list()    #####  Dataset reference: E3-Concert-Pairs.FC/NC:FC
lgtdata_LPS_XL01_wQ_ForcedChoices_HOLDOUT = list()
for(h in 1:length(lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices))
{  indexHOLDOUT = sort(sample(c(1:length(lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]])),4,replace=FALSE))
   indexINSAMPLE = setdiff(c(1:length(lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]])),indexHOLDOUT)
   lgtdata_LPS_XL01_wQ_ForcedChoices_INSAMPLE[[h]] = list()
   j=1
   for(r in indexINSAMPLE)    # for each respondent
   {  lgtdata_LPS_XL01_wQ_ForcedChoices_INSAMPLE[[h]][[j]]=lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[r]]
      j=j+1
   }
   lgtdata_LPS_XL01_wQ_ForcedChoices_INSAMPLE[[h]][[1]]$Qualtrics = lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[1]]$Qualtrics
   j=1
   lgtdata_LPS_XL01_wQ_ForcedChoices_HOLDOUT[[h]] = list()
   for(r in indexHOLDOUT)    # for each respondent
   {  lgtdata_LPS_XL01_wQ_ForcedChoices_HOLDOUT[[h]][[j]] = lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[r]]
      j=j+1
   }
   lgtdata_LPS_XL01_wQ_ForcedChoices_HOLDOUT[[h]][[1]]$Qualtrics = lgtdata_LPS_XL01_wQ_49plusch_ForcedChoices[[h]][[1]]$Qualtrics
}

# in case you want to save the workspace
save.image("E3_ConcerPairs_finalData.RData")

